summaryrefslogtreecommitdiffstats
path: root/tests/functional/quota/test_deem_statfs_quotad.py
diff options
context:
space:
mode:
authorSri Vignesh <sselvan@redhat.com>2020-05-11 12:42:48 +0530
committerBala Konda Reddy M <bala12352@gmail.com>2020-05-11 14:44:09 +0000
commit42ac4877cdba48c7ef95b0fdf1e6d708b8c9856d (patch)
tree3c35704e0c7d11f5ef719116cfe28f16c1d7b200 /tests/functional/quota/test_deem_statfs_quotad.py
parent0f2f4e2c76c3a9192fde780b9da076a4eb797759 (diff)
[TestFix][Quota] Moving test steps from teardown class to teardown
Move cases from teardown class to teardown in quota Change-Id: Ia20fe9bef09842f891f0f27ab711a1ef4c9f6f39 Signed-off-by: Sri Vignesh <sselvan@redhat.com>
Diffstat (limited to 'tests/functional/quota/test_deem_statfs_quotad.py')
-rw-r--r--tests/functional/quota/test_deem_statfs_quotad.py23
1 files changed, 10 insertions, 13 deletions
diff --git a/tests/functional/quota/test_deem_statfs_quotad.py b/tests/functional/quota/test_deem_statfs_quotad.py
index 7773d4d36..8aecfc6e6 100644
--- a/tests/functional/quota/test_deem_statfs_quotad.py
+++ b/tests/functional/quota/test_deem_statfs_quotad.py
@@ -1,4 +1,4 @@
-# Copyright (C) 2015-2018 Red Hat, Inc. <http://www.redhat.com>
+# Copyright (C) 2015-2020 Red Hat, Inc. <http://www.redhat.com>
#
# This program is free software; you can redistribute it and/or modify
# it under the terms of the GNU General Public License as published by
@@ -40,20 +40,17 @@ class QuotaDeemStatfsAndQuotad(GlusterBaseClass):
raise ExecutionError("Failed to Setup_Volume")
g.log.info("Successful in Setup Volume")
- @classmethod
- def tearDownClass(cls):
- """
- Clean up the volume
- """
- # stopping the volume and clean up the volume
- g.log.info("Starting to Cleanup Volume")
- ret = cls.cleanup_volume()
+ def tearDown(self):
+
+ # Unmount and cleanup original volume
+ g.log.info("Starting to Unmount Volume and Cleanup Volume")
+ ret = self.unmount_volume_and_cleanup_volume(mounts=self.mounts)
if not ret:
- raise ExecutionError("Failed to Cleanup Volume")
- g.log.info("Successful in Cleanup Volume")
+ raise ExecutionError("Failed to umount the vol & cleanup Volume")
+ g.log.info("Successful in umounting the volume and Cleanup")
- # calling GlusterBaseClass tearDownClass
- cls.get_super_method(cls, 'tearDownClass')()
+ # Calling GlusterBaseClass tearDown
+ self.get_super_method(self, 'tearDown')()
def test_quota_deem_statfs_quotad(self):
"""